@@ -16,20 +16,34 @@ from tiddlyweb.web.http import HTTP415, HTTP400
 from tiddlyweb.util import sha
 
 
+def content_length_and_type(environ):
+    """
+    To PUT or POST we must have content-length and content-type
+    headers. Raise 400 if we cannot get these things.
+    """
+    try:
+        length = environ['CONTENT_LENGTH']
+        content_type = environ['tiddlyweb.type']
+    except KeyError:
+        raise HTTP400(
+                'Content-Length and content-type required to PUT or POST')
+    return length, content_type
+
+
 def get_route_value(environ, name):
     """
     Retrieve and decode from UTF-8 data provided in WSGI route.
 
     If name is not present in the route, allow KeyError to raise.
 
-    If the provided data is not URI escaped UTF-8, raise and HTTP400
+    If the provided data is not URI escaped UTF-8, raise an HTTP400
     """
     try:
         value = environ['wsgiorg.routing_args'][1][name]
         value = urllib.unquote(value).decode('utf-8')
     except UnicodeDecodeError, exc:
-        raise HTTP400('incorrect encoding for %s, UTF-8 required: %s',
-                exc)
+        raise HTTP400('incorrect encoding for %s, UTF-8 required: %s'
+                % (name, exc))
     return value
 
 
